@@ -13,6 +13,8 @@
  * Documents produced by Doxygen are derivative works derived from the
  * input used in their production; they are not affected by this license.
  *
+ * Reviewed, and extented by
+ *   Jens Kallup (kallup-dev@web.de)
  * The translation into German was provided by
  *   Jens Seidel (jensseidel@users.sf.net)
  * based on work from
@@ -135,6 +137,9 @@
 //      boolean switch OPTIMIZE_OUTPUT_FOR_C
 //    - Replaced "\t" by "    "
 //
+//   2024/05/03 Jens Kallup (kallup-dev@web.de)
+//    - Updated for 1.10.0
+//
 //   Todo:
 //    - see FIXME
 
@@ -230,7 +235,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
 
     /*! this is the first part of a sentence that is followed by a class name */
     QCString trThisIsTheListOfAllMembers() override
-    { return "Vollständige Aufstellung aller Elemente für "; }
+    { return "Vollständige Aufstellung aller Elemente für"; }
 
     /*! this is the remainder of the sentence after the class name */
     QCString trIncludingInheritedMembers() override
@@ -446,8 +451,8 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
     // index titles (the project name is prepended for these)
 
     /*! This is used in HTML as the title of index.html. */
-    QCString trDocumentation() override
-    { return "Dokumentation"; }
+    QCString trDocumentation(const QCString &projName) override
+    { return (!projName.isEmpty()?projName + " " : "") + "Dokumentation"; }
 
     /*! This is used in LaTeX as the title of the chapter with the
      * index of all groups.
@@ -754,9 +759,8 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
     QCString trWriteList(int numEntries) override
     {
       QCString result;
-      int i;
       // the inherits list contain `numEntries' classes
-      for (i=0;i<numEntries;i++)
+      for (int i=0;i<numEntries;i++)
       {
         // use generateMarker to generate placeholders for the class links!
         result+=generateMarker(i); // generate marker for entry i in the list
@@ -1318,9 +1322,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trClass(bool, bool singular) override
     {
-      QCString result("Klasse");
-      if (!singular)  result+="n";
-      return result;
+      return createNoun(true, singular, "Klasse", "n");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1329,9 +1331,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trFile(bool, bool singular) override
     {
-      QCString result("Datei");
-      if (!singular)  result+="en";
-      return result;
+      return createNoun(true, singular, "Datei", "en");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1340,9 +1340,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trNamespace(bool, bool singular) override
     {
-      QCString result("Namensbereich");
-      if (!singular)  result+="e";
-      return result;
+      return createNoun(true, singular, "Namensbereich", "e");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1351,9 +1349,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trGroup(bool, bool singular) override
     {
-      QCString result("Gruppe");
-      if (!singular)  result+="n";
-      return result;
+      return createNoun(true, singular, "Gruppe", "n");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1362,9 +1358,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trPage(bool, bool singular) override
     {
-      QCString result("Seite");
-      if (!singular)  result+="n";
-      return result;
+      return createNoun(true, singular, "Seite", "n");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1373,20 +1367,16 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trMember(bool, bool singular) override
     {
-      QCString result("Element");
-      if (!singular)  result+="e";
-      return result;
+      return createNoun(true, singular, "Element", "e");
     }
 
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
      *  of the category.
      */
-    QCString trGlobal(bool first_capital, bool singular) override
+    QCString trGlobal(bool, bool singular) override
     {
-      QCString result((first_capital ? "Global" : "global")); // FIXME
-      if (!singular)  result+="";
-      return result;
+      return createNoun(true, singular, "Global", ""); // FIXME
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1398,9 +1388,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trAuthor(bool, bool singular) override
     {
-      QCString result("Autor");
-      if (!singular)  result+="en";
-      return result;
+      return createNoun(true, singular, "Autor", "en");
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1589,7 +1577,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
 
     /*! This is used in HTML as the title of page with source code for file filename
      */
-    QCString trSourceFile(QCString& filename) override
+    QCString trSourceFile(const QCString& filename) override
     {
       return filename + " Quellcode";
     }
@@ -1627,9 +1615,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trDir(bool, bool singular) override
     {
-      QCString result("Verzeichnis");
-      if (!singular) result+="se";
-      return result;
+      return createNoun(true, singular, "Verzeichnis", "se");
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1809,9 +1795,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trModule(bool /*first_capital*/, bool singular) override
     {
-      QCString result("Modul");
-      if (!singular)  result+="e";
-      return result;
+      return createNoun(true, singular, "Modul", "e");
     }
 
     /*! This is put at the bottom of a module documentation page and is
@@ -1846,9 +1830,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trType(bool /*first_capital*/, bool singular) override
     {
-      QCString result("Typ");
-      if (!singular)  result+="en";
-      return result;
+      return createNoun(true, singular, "Typ", "en");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1857,9 +1839,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
      */
     QCString trSubprogram(bool /*first_capital*/, bool singular) override
     {
-      QCString result("Unterprogramm");
-      if (!singular)  result+="e";
-      return result;
+      return createNoun(true, singular, "Unterprogramm", "e");
     }
 
     /*! C# Type Constraint list */
@@ -1968,10 +1948,10 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
       QCString text  = full? months_full[month-1] : months_short[month-1];
       return text;
     }
-    QCString trDayPeriod(int period) override
+    QCString trDayPeriod(bool period) override
     {
       static const char *dayPeriod[] = { "AM", "PM" };
-      return dayPeriod[period];
+      return dayPeriod[period?1:0];
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -2268,6 +2248,388 @@ class TranslatorGerman : public TranslatorAdapter_1_8_15
     QCString trDesignUnitDocumentation() override
     { return "Entwurfseinheiten-Dokumentation"; }
 
-};
+//////////////////////////////////////////////////////////////////////////
+// new since 1.9.2
+//////////////////////////////////////////////////////////////////////////
 
+    /** C++20 concept */
+    QCString trConcept(bool first_capital, bool singular) override
+    {
+      return createNoun(first_capital, singular, "Konzept", "Konzepte");
+    }
+    /*! used as the title of the HTML page of a C++20 concept page */
+    QCString trConceptReference(const QCString &conceptName) override
+    {
+      QCString result=conceptName;
+      result+=" Konzept Referenz";
+      return result;
+    }
+
+    /*! used as the title of page containing all the index of all concepts. */
+    QCString trConceptList() override
+    { return "Konzept Liste"; }
+
+    /*! used as the title of chapter containing the index listing all concepts. */
+    QCString trConceptIndex() override
+    { return "Konzept Index"; }
+
+    /*! used as the title of chapter containing all information about concepts. */
+    QCString trConceptDocumentation() override
+    { return "Konzept Dokumentation"; }
+
+    /*! used as an introduction to the concept list */
+    QCString trConceptListDescription(bool extractAll) override
+    {
+      QCString result="Hier folgt eine Lister aller ";
+      if (!extractAll) result+="dokumentierten ";
+      result+="Konzepte mit Kurzbeschreibungen:";
+      return result;
+    }
+
+    /*! used to introduce the definition of the C++20 concept */
+    QCString trConceptDefinition() override
+    {
+      return "Konzept-Definition";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.9.4
+//////////////////////////////////////////////////////////////////////////
+
+    QCString trPackageList() override
+    { return "Paket-Liste"; }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.9.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used for translation of the word that will be
+     *  followed by a single name of the VHDL process flowchart.
+     */
+    QCString trFlowchart() override
+    { return "Flußdiagram:"; }
+
+    /*! Please translate also updated body of the method
+     *  trMemberFunctionDocumentation(), now better adapted for
+     *  VHDL sources documentation.
+     */
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.9.7
+//////////////////////////////////////////////////////////////////////////
+    /*! used in the compound documentation before a list of related symbols.
+     *
+     *  Supersedes trRelatedFunctions
+     */
+    QCString trRelatedSymbols() override
+    { return "Zugehörige Symbole"; }
+
+    /*! subscript for the related symbols
+     *
+     *  Supersedes trRelatedSubscript
+     */
+    QCString trRelatedSymbolsSubscript() override
+    { return "(Hinweis: diese Symbole sind keine Funktionen.)"; }
+
+    /*! used in the class documentation as a header before the list of all
+     * related classes.
+     *
+     * Supersedes trRelatedFunctionDocumentation
+     */
+    QCString trRelatedSymbolDocumentation() override
+    { return "Freunde und bezugnehmende Symbol-Dokumentation"; }
+
+    /*! the compound type as used for the xrefitems */
+    QCString trCompoundType(ClassDef::CompoundType compType, SrcLangExt lang) override
+    {
+      QCString result;
+      switch(compType)
+      {
+        case ClassDef::Class:
+          if (lang == SrcLangExt::Fortran) trType(true,true);
+          else result=trClass(true,true);
+          break;
+        case ClassDef::Struct:     result="Struct"; break;
+        case ClassDef::Union:      result="Union"; break;
+        case ClassDef::Interface:  result="Interface"; break;
+        case ClassDef::Protocol:   result="Protocol"; break;
+        case ClassDef::Category:   result="Category"; break;
+        case ClassDef::Exception:  result="Exception"; break;
+        case ClassDef::Service:    result="Service"; break;
+        case ClassDef::Singleton:  result="Singleton"; break;
+        default: break;
+      }
+      return result;
+    }
+
+    QCString trFileMembersDescriptionTotal(FileMemberHighlight::Enum hl) override
+    {
+      bool extractAll = Config_getBool(EXTRACT_ALL);
+      QCString result="Hier ist eine Lister aller ";
+      if (!extractAll) result+="documented ";
+
+      switch (hl)
+      {
+        case FileMemberHighlight::All:
+          if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+          {
+            result+="functions, variables, defines, enums, and typedefs";
+          }
+          else
+          {
+            result+="zugehöriger Dateien";
+          }
+          break;
+        case FileMemberHighlight::Functions:
+          result+="Funktionen";
+          break;
+        case FileMemberHighlight::Variables:
+          result+="Variablen";
+          break;
+        case FileMemberHighlight::Typedefs:
+          result+="Typen-Definitionen";
+          break;
+        case FileMemberHighlight::Sequences:
+          result+="Abfolgen";
+          break;
+        case FileMemberHighlight::Dictionaries:
+          result+="Wörterbücher";
+          break;
+        case FileMemberHighlight::Enums:
+          result+="Aufzählungen";
+          break;
+        case FileMemberHighlight::EnumValues:
+          result+="Aufzählungs-Werte";
+          break;
+        case FileMemberHighlight::Defines:
+          result+="Makros";
+          break;
+        case FileMemberHighlight::Total: // for completeness
+          break;
+      }
+      result+=" mit verweisen auf ";
+      if (extractAll)
+        result+="bezugnehmenden Dateien:";
+      else
+        result+="die Dokumentation";
+      return result;
+    }
+    QCString trCompoundMembersDescriptionTotal(ClassMemberHighlight::Enum hl) override
+    {
+      bool extractAll = Config_getBool(EXTRACT_ALL);
+      QCString result="Hier ist eine Liste aller ";
+      if (!extractAll)
+      {
+        result+="dokumentierter ";
+      }
+
+      switch (hl)
+      {
+        case ClassMemberHighlight::All:
+          if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+          {
+            result+="Struktur- und Einheits-Felder";
+          }
+          else
+          {
+            result+="Klassen-Funktionen";
+          }
+          break;
+        case ClassMemberHighlight::Functions:
+          result+="Funktionen";
+          break;
+        case ClassMemberHighlight::Variables:
+          result+="Variablen";
+          break;
+        case ClassMemberHighlight::Typedefs:
+          result+="Typen-Definitionen";
+          break;
+        case ClassMemberHighlight::Enums:
+          result+="Aufzählungen";
+          break;
+        case ClassMemberHighlight::EnumValues:
+          result+="Aufzählungs-Werte";
+          break;
+        case ClassMemberHighlight::Properties:
+          result+="Eigenschaften";
+          break;
+        case ClassMemberHighlight::Events:
+          result+="Ereignisse";
+          break;
+        case ClassMemberHighlight::Related:
+          result+="zugehörige Symbole";
+          break;
+        case ClassMemberHighlight::Total: // for completeness
+          break;
+      }
+      result+=" mit Verweisen auf ";
+      if (!extractAll)
+      {
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+        {
+          result+="die struct/union Dokumentation für jedes Feld:";
+        }
+        else
+        {
+          result+="die Klassen-Dokumentation für jede Funktion:";
+        }
+      }
+      else
+      {
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+        {
+          result+="die Strukturen/Einheiten auf denen sie sich beziehen:";
+        }
+        else
+        {
+          result+="die Klassen auf denen sie sich beziehen:";
+        }
+      }
+      return result;
+    }
+    QCString trNamespaceMembersDescriptionTotal(NamespaceMemberHighlight::Enum hl) override
+    {
+      bool extractAll = Config_getBool(EXTRACT_ALL);
+      
+      QCString result           = "Hier folgt eine Liste mit Verweisen auf die Namensraum-Dokumentation für ";
+      QCString result_singular1 = result + "jede dokumentierte";
+      QCString result_singular2 = result + "jedes dokumentiertes";
+      QCString result_singular3 = result + "jeder dokumentierten";
+      QCString result_plural    = result + "alle dokumentierten";
+      
+      QCString singularResult = "";
+      QCString pluralResult   = "";
+      
+      switch (hl)
+      {
+        case NamespaceMemberHighlight::All:
+          singularResult = result_singular2 + "Mitglied";
+          pluralResult   = result_plural    + "Mitglieder";
+          break;
+        case NamespaceMemberHighlight::Functions:
+          singularResult = result_singular1 + "Funktion";
+          pluralResult   = result_plural    + "Funktionen";
+          break;
+        case NamespaceMemberHighlight::Variables:
+          singularResult = result_singular1 + "Variable";
+          pluralResult   = result_plural    + "Variablen";
+          break;
+        case NamespaceMemberHighlight::Typedefs:
+          singularResult = result_singular1 + "Typ-Definition";
+          pluralResult   = result_plural    + "Typen-Defintionen";
+          break;
+        case NamespaceMemberHighlight::Sequences:
+          singularResult = result_singular1 + "Abfolge";
+          pluralResult   = result_plural    + "Abfolgen";
+          break;
+        case NamespaceMemberHighlight::Dictionaries:
+          singularResult = result_singular2 + "Wörterbuch";
+          pluralResult   = result_plural    + "Wörterbücher";
+          break;
+        case NamespaceMemberHighlight::Enums:
+          singularResult = result_singular3 + "Aufzählung";
+          pluralResult   = result_plural    + "Aufzählungen";
+          break;
+        case NamespaceMemberHighlight::EnumValues:
+          singularResult = result_singular3 + "Aufzählung";
+          pluralResult   = result_plural    + "Aufzählungen";
+          break;
+        case NamespaceMemberHighlight::Total: // for completeness
+          break;
+      }
+
+      // TODO: plural form !!!
+      if (!extractAll)
+        result += singularResult + " mit Verweise auf die Namensraum-Dokumentation:"; else
+        result += singularResult + " mit Verweise auf dem sich beziehenden Namensraum:";
+          
+      return result;
+    }
+    QCString trDefinition() override  { return "Definition";}
+    QCString trDeclaration() override { return "Deklaration";}
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.10.0 added by paule32
+//////////////////////////////////////////////////////////////////////////
+
+    QCString trTopics() override
+    { return "Themen"; }
+    QCString trTopicDocumentation() override
+    { return "Themen Dokumentation"; }
+    QCString trTopicList() override
+    { return "Themen-Liste"; }
+    QCString trTopicIndex() override
+    { return "Themen Index"; }
+    QCString trTopicListDescription() override
+    { return "Es folgt eine Liste der Themen mit einer Kurzbeschreibung"; }
+    QCString trModuleMembersDescriptionTotal(ModuleMemberHighlight::Enum hl) override
+    {
+      bool extractAll = Config_getBool(EXTRACT_ALL);
+      QCString result = "Zusammengefaßt ";
+      
+      QCString singularResult = result + "bezieht sich das Modul auf: ";
+      QCString pluralResult   = result + "beziehen sich die Module auf: ";
+      
+      switch (hl)
+      {
+        case ModuleMemberHighlight::All:
+          if (!extractAll)
+              singularResult += "die verlinkte Modul-Beschreibung für jedes Mitglied:"; else
+              pluralResult   += "die verlinkten Modul-Beschreibungen aller Mitglieder:";
+          break;
+        case ModuleMemberHighlight::Functions:
+          if (!extractAll)
+              singularResult += "die verlinkte Modul-Beschreibung für jede Funktion:"; else
+              pluralResult   += "die verlinkten Modul-Beschreibungen aller Funktionen:";
+          break;
+        case ModuleMemberHighlight::Variables:
+          if (!extractAll)
+              singularResult += "die verlinkte Modul-Beschreibung für jede Variable:"; else
+              pluralResult   += "die verlinkten Modul-Beschreibungen für alle Variablen:";
+          break;
+        case ModuleMemberHighlight::Typedefs:
+          if (!extractAll)
+              singularResult += "die verlinkte Modul-Beschreibung für jede Typ-Definition:"; else
+              pluralResult   += "die verlinkten Modul-Beschreibungen für jeden Definitions-Typen:";
+          break;
+        case ModuleMemberHighlight::Enums:
+          if (!extractAll)
+              singularResult += "die verlinkte Modul-Beschreibung für jede Aufzählung:"; else
+              pluralResult   += "die verlinkten Modul-Beschreibungen aller Aufzählungen:";
+          break;
+        case ModuleMemberHighlight::EnumValues:
+          if (!extractAll)
+              singularResult += "die verlinkte Modul-Beschreibung für jedem Aufzählungswert:"; else
+              pluralResult   += "die verlinkten Modul-Beschreibungen aller Aufzählungswerte:";
+          break;
+        case ModuleMemberHighlight::Total: // for completeness
+          break;
+      }
+      if (!extractAll)
+        result = singularResult; else
+        result = pluralResult;
+      
+      return result;
+    }
+    QCString trExportedModules() override
+    {
+      return "Exportierte Module";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.10.0
+//////////////////////////////////////////////////////////////////////////
+
+    QCString trCopyToClipboard() override
+    {
+      return "In die Zwischenablage kopieren";
+    }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.11.0
+//////////////////////////////////////////////////////////////////////////
+    QCString trImportant() override
+    {
+      return "Wichtig";
+    }
+};
 #endif
