@@ -38,26 +38,26 @@ enum class RelatesType  { Simple, Duplicate, MemberOf };
 enum class Relationship { Member, Related, Foreign };
 
 /** Language as given by extension */
-enum SrcLangExt
+enum class SrcLangExt
 {
-  SrcLangExt_Unknown  = 0x00000,
-  SrcLangExt_IDL      = 0x00008,
-  SrcLangExt_Java     = 0x00010,
-  SrcLangExt_CSharp   = 0x00020,
-  SrcLangExt_D        = 0x00040,
-  SrcLangExt_PHP      = 0x00080,
-  SrcLangExt_ObjC     = 0x00100,
-  SrcLangExt_Cpp      = 0x00200,
-  SrcLangExt_JS       = 0x00400,
-  SrcLangExt_Python   = 0x00800,
-  SrcLangExt_Fortran  = 0x01000,
-  SrcLangExt_VHDL     = 0x02000,
-  SrcLangExt_XML      = 0x04000,
-  //SrcLangExt_Tcl      = 0x08000, // no longer supported
-  SrcLangExt_Markdown = 0x10000,
-  SrcLangExt_SQL      = 0x20000,
-  SrcLangExt_Slice    = 0x40000,
-  SrcLangExt_Lex      = 0x80000
+  Unknown  = 0x00000,
+  IDL      = 0x00008,
+  Java     = 0x00010,
+  CSharp   = 0x00020,
+  D        = 0x00040,
+  PHP      = 0x00080,
+  ObjC     = 0x00100,
+  Cpp      = 0x00200,
+  JS       = 0x00400,
+  Python   = 0x00800,
+  Fortran  = 0x01000,
+  VHDL     = 0x02000,
+  XML      = 0x04000,
+  //Tcl      = 0x08000, // no longer supported
+  Markdown = 0x10000,
+  SQL      = 0x20000,
+  Slice    = 0x40000,
+  Lex      = 0x80000
 };
 
 /** Grouping info */
@@ -272,7 +272,7 @@ constexpr const char *codeSymbolType2Str(CodeSymbolType type)
     case CodeSymbolType::Sequence:    return "sequence";
     case CodeSymbolType::Dictionary:  return "dictionary";
     default:
-      return 0;
+      return nullptr;
   }
 }
 
@@ -373,7 +373,8 @@ class LocalToc
 /* 45 */ TSPEC(Strong)            TSPEC(Weak)            TSPEC(Unretained)        TSPEC(Alias)        TSPEC(ConstExp)           \
 /* 50 */ TSPEC(Default)           TSPEC(Delete)          TSPEC(NoExcept)          TSPEC(Attribute)    TSPEC(Property)           \
 /* 55 */ TSPEC(Readonly)          TSPEC(Bound)           TSPEC(Constrained)       TSPEC(Transient)    TSPEC(MaybeVoid)          \
-/* 60 */ TSPEC(MaybeDefault)      TSPEC(MaybeAmbiguous)  TSPEC(Published)
+/* 60 */ TSPEC(MaybeDefault)      TSPEC(MaybeAmbiguous)  TSPEC(Published)         TSPEC(ConstEval)    TSPEC(ConstInit)          \
+/* 65 */ TSPEC(NoDiscard)
 
 /** Wrapper class for a number of boolean properties.
  *  The properties are packed together, and initialized to false.
